SCALAR period_length    'length of modelling periods'
        / 10 / ;

SCALAR import_dummy     'cost for non grid-bound energycarrier import between model regions'
        / 2.000e-004 / ;

SCALAR annuity_type      'annuity type (0 = annuity in arrears (nachschuessig), 1 = annuity in advance (vorschuessig))'
        / 1 / ;

SCALAR report_year       'report year at beginning (= -1) or end (= +1) of period (inner periodical discounting)'
        / +1 / ;

PARAMETER interest(model_region, sector)
/
        world.primary_energy     0.05
        world.conversion         0.05
        world.end_use            0.05
/ ;

TABLE demand_regional(model_region, demand, period)
                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
         world.electric          1.455   1.812   2.661   3.539   4.592   5.652   6.811   7.884   8.917   9.879   10.645
         world.non_electric      5.357   6.402   8.438   9.428   10.325  11.046  11.347  11.428  11.446  11.496  11.481
         world.transport         2.369   3.032   3.998   4.836   5.523   6.034   6.369   6.626   6.967   7.420   7.822
;

TABLE technical_lifetime(model_region, technology, year)
                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr          10      10      10      10      10      10      10      10      10      10      10
        world.oil_extr_1         10      10      10      10      10      10      10      10      10      10      10
        world.oil_extr_4         10      10      10      10      10      10      10      10      10      10      10
        world.gas_extr_1         10      10      10      10      10      10      10      10      10      10      10
        world.gas_extr_5         10      10      10      10      10      10      10      10      10      10      10
        world.bio_extr_1         10      10      10      10      10      10      10      10      10      10      10
        world.bio_extr_2         10      10      10      10      10      10      10      10      10      10      10
* power generation
        world.coal_ppl           30      30      30      30      30      30      30      30      30      30      30
        world.gas_cc             30      30      30      30      30      30      30      30      30      30      30
        world.nuc_hc             30      30      30      30      30      30      30      30      30      30      30
        world.bio_ppl            30      30      30      30      30      30      30      30      30      30      30
        world.hydro_hc           60      60      60      60      60      60      60      60      60      60      60
        world.wind_ppl           30      30      30      30      30      30      30      30      30      30      30
        world.wind_ppl2          30      30      30      30      30      30      30      30      30      30      30
        world.solar_pv_ppl       30      30      30      30      30      30      30      30      30      30      30
        world.backup_elc         30      30      30      30      30      30      30      30      30      30      30
* CCS
        world.g_ppl_co2scr       30      30      30      30      30      30      30      30      30      30      30
        world.c_ppl_co2scr       30      30      30      30      30      30      30      30      30      30      30
        world.bio_ppl_co2scr     30      30      30      30      30      30      30      30      30      30      30
* other conversion
        world.h2_elec            30      30      30      30      30      30      30      30      30      30      30
        world.meth_coal          30      30      30      30      30      30      30      30      30      30      30
        world.meth_ng            30      30      30      30      30      30      30      30      30      30      30
        world.eth_bio            30      30      30      30      30      30      30      30      30      30      30
        world.ref_lol            30      30      30      30      30      30      30      30      30      30      30
* transport and distribution
        world.elec_t_d           60      60      60      60      60      60      60      60      60      60      60
        world.gas_t_d            40      40      40      40      40      40      40      40      40      40      40
;

PARAMETER economic_lifetime(model_region, technology, year) ;
economic_lifetime(model_region, technology, year) = technical_lifetime(model_region, technology, year) ;

TABLE availability(model_region, technology, year)
                                         2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr                  1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.oil_extr_1                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.oil_extr_4                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_extr_1                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_extr_5                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.bio_extr_1                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.bio_extr_2                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.nuc_imp                    1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* power generation
        world.coal_ppl                   0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.gas_cc                     0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.nuc_hc                     0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.bio_ppl                    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.hydro_hc                   0.42    0.42    0.42    0.42    0.42    0.42    0.42    0.42    0.42    0.42    0.42
        world.wind_ppl                   0.34    0.34    0.34    0.34    0.34    0.34    0.34    0.34    0.34    0.34    0.34
        world.wind_ppl2                  0.22    0.22    0.22    0.22    0.22    0.22    0.22    0.22    0.22    0.22    0.22
        world.solar_pv_ppl               0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25
        world.backup_elc                 0.5     0.5     0.5     0.5     0.5     0.5     0.5     0.5     0.5     0.5     0.5
* CCS
        world.g_ppl_co2scr               0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.c_ppl_co2scr               0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
        world.bio_ppl_co2scr             0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75    0.75
* other conversion
        world.h2_elec                    0.95    0.95    0.95    0.95    0.95    0.95    0.95    0.95    0.95    0.95    0.95
        world.meth_coal                  0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9
        world.meth_ng                    0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9
        world.eth_bio                    0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9
        world.ref_lol                    0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9     0.9
* transport and distribution
        world.elec_t_d                   0.55    0.55    0.55    0.55    0.55    0.55    0.55    0.55    0.55    0.55    0.55
        world.gas_t_d                    0.7     0.7     0.7     0.7     0.7     0.7     0.7     0.7     0.7     0.7     0.7
* end-use
        world.enduse_electric_std        1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_electric_save1      1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_electric_save2      1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_std    1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_save1  1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_save2  1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_std       1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_save1     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_save2     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
;

TABLE inv_cost(model_region, technology, year)
                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr          130     130     130     130     130     130     130     130     130     130     130
        world.oil_extr_1         150     150     150     150     150     150     150     150     150     150     150
        world.oil_extr_4         225     225     225     225     225     225     225     225     225     225     225
        world.gas_extr_1         100     100     100     100     100     100     100     100     100     100     100
        world.gas_extr_5         180     180     180     180     180     180     180     180     180     180     180
* power generation
        world.coal_ppl           1300    1246    1206    1176    1154    1137    1125    1116    1109    1104    1100
        world.gas_cc             716     602     529     482     451     432     419     411     406     402     400
        world.nuc_hc             2500    2279    2126    2020    1946    1896    1861    1836    1820    1808    1800
        world.bio_ppl            1567    1456    1378    1323    1283    1255    1236    1222    1212    1205    1200
        world.hydro_hc           2500    2500    2500    2500    2500    2500    2500    2500    2500    2500    2500
        world.wind_ppl           1344    1057    880     770     703     661     635     620     610     604     600
        world.wind_ppl2          1344    1057    880     770     703     661     635     620     610     604     600
        world.solar_pv_ppl       4756    3071    2140    1626    1341    1184    1097    1049    1023    1008    1000
        world.backup_elc         500     500     500     500     500     500     500     500     500     500     500
* CCS
        world.g_ppl_co2scr       503     503     503     503     503     503     503     503     503     503     503
        world.c_ppl_co2scr       705     705     705     705     705     705     705     705     705     705     705
        world.bio_ppl_co2scr     846     846     846     846     846     846     846     846     846     846     846
* other conversion
        world.h2_elec            452     432     418     407     399     393     389     386     383     381     380
        world.meth_coal          1350    1297    1257    1227    1204    1188    1175    1166    1159    1154    1150
        world.meth_ng            630     585     552     530     514     502     494     489     485     482     480
        world.eth_bio            1400    1037    821     692     615     569     542     526     516     510     507
        world.ref_lol            66      66      66      66      66      66      66      66      66      66      66
* transport and distribution
        world.elec_t_d           800     800     800     800     800     800     800     800     800     800     800
        world.gas_t_d            200     200     200     200     200     200     200     200     200     200     200
;

TABLE dec_cost(model_region, technology, year)
;

TABLE fix_cost(model_region, technology, year)
                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* power generation
        world.coal_ppl           74.0    70.9    68.6    66.9    65.7    64.7    64.0    63.5    63.1    62.8    62.6
        world.gas_cc             51      49      47      44      41      37      35      34      34      33      32
        world.nuc_hc             108     108     105     102     99      99      99      99      99      99      99
        world.bio_ppl            82      78      75      72      68      68      68      68      68      68      68
        world.hydro_hc           40      40      40      40      40      40      40      40      40      40      40
        world.wind_ppl           56      51      46      42      37      37      37      37      37      37      37
        world.wind_ppl2          56      51      46      42      37      37      37      37      37      37      37
        world.solar_pv_ppl       111     95      80      64      48      48      48      48      48      48      48
        world.backup_elc         20      20      20      20      20      20      20      20      20      20      20
* other conversion
        world.h2_elec            20.0    20.0    18.0    17.0    15.0    15.0    15.0    15.0    15.0    15.0    15.0
        world.meth_coal          76      76      76      76      76      76      76      76      76      76      76
        world.meth_ng            46      46      42      39      35      35      35      35      35      35      35
        world.eth_bio            74      74      68      62      55      55      55      55      55      55      55
        world.ref_lol            7.5     7.5     7.5     7.5     7.5     7.5     7.5     7.5     7.5     7.5     7.5
* transport and distribution
        world.elec_t_d           55      55      55      55      55      55      55      55      55      55      55
        world.gas_t_d            24      24      24      24      24      24      24      24      24      24      24
;

TABLE var_cost(model_region, technology, year)
                                         2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr                  35      35      35      35      35      35      35      35      35      35      35
        world.oil_extr_1                 80      80      80      80      80      80      80      80      80      80      80
        world.oil_extr_4                 140     140     140     140     140     140     140     140     140     140     140
* gas extraction includes variable inter-regional transportation costs of 30 $/kWyr
        world.gas_extr_1                 75      75      75      75      75      75      75      75      75      75      75
        world.gas_extr_5                 160     160     160     160     160     160     160     160     160     160     160
        world.bio_extr_1                 65      65      65      65      65      65      65      65      65      65      65
        world.bio_extr_2                 125     125     125     125     125     125     125     125     125     125     125
        world.nuc_imp                    30      30      30      30      30      30      30      30      30      30      30
* CCS
        world.g_ppl_co2scr               19.8    19.8    19.8    19.8    19.8    19.8    19.8    19.8    19.8    19.8    19.8
        world.c_ppl_co2scr               55.9    55.9    55.9    55.9    55.9    55.9    55.9    55.9    55.9    55.9    55.9
* vom include additional CO2 transportation and disposal costs for biomass power plants due to smaller size
        world.bio_ppl_co2scr             108.9   108.9   108.9   108.9   108.9   108.9   108.9   108.9   108.9   108.9   108.9
* other conversion
        world.h2_elec                    4       4       4       4       4       4       4       4       4       4       4
        world.meth_coal                  10      10      10      10      10      10      10      10      10      10      10
        world.meth_ng                    5.4     5.4     5.4     5.4     5.4     5.4     5.4     5.4     5.4     5.4     5.4
        world.eth_bio                    8       8       8       8       8       8       8       8       8       8       8
        world.ref_lol                    0       0       0       0       0       0       0       0       0       0       0
* transport and distribution
        world.elec_t_d                   18      18      18      18      18      18      18      18      18      18      18
        world.gas_t_d                    3.5     3.5     3.5     3.5     3.5     3.5     3.5     3.5     3.5     3.5     3.5
* end-use (new data set - exponential interpolation; elasticities and potentials derived from B2 MESSAGE-MACRO runs by Ilkka)
        world.enduse_electric_save1      514.7   523.8   533.2   542.6   552.3   562.1   572.1   582.2   592.6   603.1   613.8
        world.enduse_electric_save2      595.3   604.4   613.6   623.0   632.5   642.2   652.0   662.0   672.1   682.3   692.8
        world.enduse_non_electric_save1  117.7   130.1   143.9   159.1   175.9   194.5   215.1   237.8   263.0   290.8   321.5
        world.enduse_non_electric_save2  115.6   135.7   159.3   186.9   219.4   257.6   302.3   354.9   416.6   488.9   573.9
        world.enduse_transport_save1     111.3   126.3   143.3   162.6   184.5   209.4   237.6   269.6   305.9   347.1   393.8
        world.enduse_transport_save2     114.7   135.1   159.2   187.5   221.0   260.3   306.7   361.3   425.6   501.4   590.7
;

TABLE input(model_region, technology, energycarrier, level, year)
                                                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr.coal.resource                            1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.oil_extr_1.oil_conventional.resource               1.0417  1.0417  1.0417  1.0417  1.0417  1.0417  1.0417  1.0417  1.0417  1.0417  1.0417
        world.oil_extr_4.oil_unconventional.resource             1.2121  1.2121  1.2121  1.2121  1.2121  1.2121  1.2121  1.2121  1.2121  1.2121  1.2121
        world.gas_extr_1.gas_conventional.resource               1.0309  1.0309  1.0309  1.0309  1.0309  1.0309  1.0309  1.0309  1.0309  1.0309  1.0309
        world.gas_extr_5.gas_unconventional.resource             1.0870  1.0870  1.0870  1.0870  1.0870  1.0870  1.0870  1.0870  1.0870  1.0870  1.0870
* power generation
        world.coal_ppl.coal.primary                              2.6316  2.6316  2.6316  2.6316  2.6316  2.6316  2.6316  2.6316  2.6316  2.6316  2.6316
        world.gas_cc.gas.primary                                 2.0     2.0     2.0     2.0     2.0     2.0     2.0     2.0     2.0     2.0     2.0
        world.nuc_hc.nuclear.primary                             3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303
        world.bio_ppl.biomass.primary                            3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303  3.0303
        world.hydro_hc.hydro.primary                             2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641
        world.wind_ppl.wind.primary                              2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641
        world.wind_ppl2.wind.primary                             2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641
        world.solar_pv_ppl.solar.primary                         2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641  2.5641
        world.backup_elc.electricity.secondary                   0.2     0.2     0.2     0.2     0.2     0.2     0.2     0.2     0.2     0.2     0.2
* CCS
        world.g_ppl_co2scr.electricity.secondary                 0.13    0.13    0.13    0.13    0.13    0.13    0.13    0.13    0.13    0.13    0.13
        world.c_ppl_co2scr.electricity.secondary                 0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25
        world.bio_ppl_co2scr.electricity.secondary               0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25    0.25
* other conversion
        world.h2_elec.electricity.secondary                      1.25    1.25    1.25    1.25    1.25    1.25    1.25    1.25    1.25    1.25    1.25
        world.meth_coal.coal.primary                             1.5385  1.5385  1.5385  1.5385  1.5385  1.5385  1.5385  1.5385  1.5385  1.5385  1.5385
        world.meth_coal.electricity.secondary                    0.0462  0.0462  0.0462  0.0462  0.0462  0.0462  0.0462  0.0462  0.0462  0.0462  0.0462
        world.meth_ng.gas.primary                                1.4286  1.4286  1.4286  1.4286  1.4286  1.4286  1.4286  1.4286  1.4286  1.4286  1.4286
        world.meth_ng.electricity.secondary                      0.0429  0.0429  0.0429  0.0429  0.0429  0.0429  0.0429  0.0429  0.0429  0.0429  0.0429
        world.eth_bio.biomass.primary                            1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111
        world.eth_bio.electricity.secondary                      0.0333  0.0333  0.0333  0.0333  0.0333  0.0333  0.0333  0.0333  0.0333  0.0333  0.0333
        world.ref_lol.oil.primary                                1.0753  1.0753  1.0753  1.0753  1.0753  1.0753  1.0753  1.0753  1.0753  1.0753  1.0753
* transport and distribution
        world.elec_t_d.electricity.secondary                     1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111  1.1111
        world.gas_t_d.gas.primary                                1.0526  1.0526  1.0526  1.0526  1.0526  1.0526  1.0526  1.0526  1.0526  1.0526  1.0526
        world.liquids_t_d.liquids.secondary                      1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* end-use
        world.enduse_electric_std.electricity.final              1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_std.non_electric.final         1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_std.transport.final               1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* aggregation
        world.enduse_non_electric_liquids.liquids.final          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_solids.solids.final            1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_gaseous.gas.final              1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_electric.electricity.final     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_liquids.liquids.final             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.coal_solids.coal.primary                           1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.biomass_solids.biomass.primary                     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
;

TABLE output(model_region, technology, energycarrier, level, year)
                                                                 2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.coal_extr.coal.primary                             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.oil_extr_1.oil.primary                             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.oil_extr_4.oil.primary                             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_extr_1.gas.primary                             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_extr_5.gas.primary                             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.bio_extr_1.biomass.primary                         1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.bio_extr_2.biomass.primary                         1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.nuc_imp.nuclear.primary                            1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.hydro_pot.hydro.primary                            1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.wind_pot.wind.primary                              1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.solar_pot.solar.primary                            1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* power generation
        world.coal_ppl.electricity.secondary                     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_cc.electricity.secondary                       1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.nuc_hc.electricity.secondary                       1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.bio_ppl.electricity.secondary                      1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.hydro_hc.electricity.secondary                     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.wind_ppl.electricity.secondary                     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.wind_ppl2.electricity.secondary                    1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.solar_pv_ppl.electricity.secondary                 1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* other conversion
        world.h2_elec.liquids.secondary                          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.meth_coal.liquids.secondary                        1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.meth_ng.liquids.secondary                          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.eth_bio.liquids.secondary                          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.ref_lol.liquids.secondary                          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* transport and distribution
        world.elec_t_d.electricity.final                         1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.gas_t_d.gas.final                                  1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.liquids_t_d.liquids.final                          1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
* aggregation
        world.enduse_non_electric_liquids.non_electric.final     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_solids.non_electric.final      1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_gaseous.non_electric.final     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_electric.non_electric.final    1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_liquids.transport.final           1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.coal_solids.solids.final                           1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.biomass_solids.solids.final                        1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
;

TABLE emission_output(model_region, technology, emission, year)
                                                         2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
* resource extraction
        world.oil_extr_1.CO2                             0.0263  0.0263  0.0263  0.0263  0.0263  0.0263  0.0263  0.0263  0.0263  0.0263  0.0263
        world.oil_extr_4.CO2                             0.1338  0.1338  0.1338  0.1338  0.1338  0.1338  0.1338  0.1338  0.1338  0.1338  0.1338
        world.gas_extr_1.CO2                             0.0149  0.0149  0.0149  0.0149  0.0149  0.0149  0.0149  0.0149  0.0149  0.0149  0.0149
        world.gas_extr_5.CO2                             0.0419  0.0419  0.0419  0.0419  0.0419  0.0419  0.0419  0.0419  0.0419  0.0419  0.0419
* power generation
        world.coal_ppl.CO2                               2.1421  2.1421  2.1421  2.1421  2.1421  2.1421  2.1421  2.1421  2.1421  2.1421  2.1421
        world.gas_cc.CO2                                 0.964   0.964   0.964   0.964   0.964   0.964   0.964   0.964   0.964   0.964   0.964
* CCS
        world.g_ppl_co2scr.CO2                           -0.788  -0.788  -0.788  -0.788  -0.788  -0.788  -0.788  -0.788  -0.788  -0.788  -0.788
        world.c_ppl_co2scr.CO2                           -1.925  -1.925  -1.925  -1.925  -1.925  -1.925  -1.925  -1.925  -1.925  -1.925  -1.925
        world.bio_ppl_co2scr.CO2                         -2.57   -2.57   -2.57   -2.57   -2.57   -2.57   -2.57   -2.57   -2.57   -2.57   -2.57
        world.g_ppl_co2scr.CO2_CCS                       0.788   0.788   0.788   0.788   0.788   0.788   0.788   0.788   0.788   0.788   0.788
        world.c_ppl_co2scr.CO2_CCS                       1.925   1.925   1.925   1.925   1.925   1.925   1.925   1.925   1.925   1.925   1.925
        world.bio_ppl_co2scr.CO2_CCS                     2.57    2.57    2.57    2.57    2.57    2.57    2.57    2.57    2.57    2.57    2.57
* other conversion (liquids): emissions include end-use of liquids!
        world.meth_coal.CO2                              1.2523  1.2523  1.2523  1.2523  1.2523  1.2523  1.2523  1.2523  1.2523  1.2523  1.2523
        world.meth_ng.CO2                                0.6886  0.6886  0.6886  0.6886  0.6886  0.6886  0.6886  0.6886  0.6886  0.6886  0.6886
        world.ref_lol.CO2                                0.6785  0.6785  0.6785  0.6785  0.6785  0.6785  0.6785  0.6785  0.6785  0.6785  0.6785
* transport and distribution
        world.gas_t_d.CO2                                0.02537 0.02537 0.02537 0.02537 0.02537 0.02537 0.02537 0.02537 0.02537 0.02537 0.02537
* aggregation
        world.coal_solids.CO2                            0.814   0.814   0.814   0.814   0.814   0.814   0.814   0.814   0.814   0.814   0.814
        world.enduse_non_electric_gaseous.CO2            0.482   0.482   0.482   0.482   0.482   0.482   0.482   0.482   0.482   0.482   0.482
;

TABLE demand_output(model_region, demand_technology, demand, year)
                                                         2000    2010    2020    2030    2040    2050    2060    2070    2080    2090    2100
        world.enduse_electric_std.electric               1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_electric_save1.electric             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_electric_save2.electric             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_std.non_electric       1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_save1.non_electric     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_non_electric_save2.non_electric     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_std.transport             1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_save1.transport           1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
        world.enduse_transport_save2.transport           1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0     1.0
;

TABLE demand_input(model_region, demand_technology, demand, year)
;

PARAMETER volume(model_region, energycarrier, level)
/
         world.coal.resource                     8258.815
         world.oil_conventional.resource         373.224
         world.oil_unconventional.resource       281.900
         world.gas_conventional.resource         568.239
         world.gas_unconventional.resource       729.959
/ ;

PARAMETER tax_energy_total(energycarrier, period)
/
/ ;

PARAMETER tax_energy_regional(model_region, energycarrier, period)
/
/ ;

PARAMETER tax_energy_sectoral(model_region, sector, energycarrier, period)
/
/ ;

PARAMETER tax_emission_cumulative(emission)
/
* >650ppm carbon price (IPCC scenario data base analysis)
*         CO2     372
* <650ppm carbon price (IPCC scenario data base analysis)
*         CO2     690
/ ;

PARAMETER tax_emission_total(emission, period)
/
/ ;

PARAMETER tax_emission_regional(model_region, emission, period)
/
* >650ppm carbon price (IPCC scenario data base analysis)
         world.CO2.2010          4.61
         world.CO2.2020          7.51
         world.CO2.2030          12.2
         world.CO2.2040          19.9
         world.CO2.2050          32.4
         world.CO2.2060          52.8
         world.CO2.2070          86.1
         world.CO2.2080          140
         world.CO2.2090          228
         world.CO2.2100          372
/ ;

PARAMETER tax_emission_sectoral(model_region, sector, emission, period)
/
/ ;

PARAMETER r_bound_capacity(period, model_region, technology, year, bound_type)
/
         2000.world.coal_ppl.1980.FX             .336
         2000.world.coal_ppl.1990.FX             .336
         2000.world.coal_ppl.2000.FX             .336
         2000.world.gas_cc.1980.FX               .1607
         2000.world.gas_cc.1990.FX               .1607
         2000.world.gas_cc.2000.FX               .1607
         2000.world.nuc_hc.1980.FX               .1298
         2000.world.nuc_hc.1990.FX               .1298
         2000.world.nuc_hc.2000.FX               .1298
         2000.world.bio_ppl.1980.FX              .0123
         2000.world.bio_ppl.1990.FX              .0123
         2000.world.bio_ppl.2000.FX              .0123
         2000.world.hydro_hc.1950.FX             .1135
         2000.world.hydro_hc.1960.FX             .1135
         2000.world.hydro_hc.1970.FX             .1135
         2000.world.hydro_hc.1980.FX             .1135
         2000.world.hydro_hc.1990.FX             .1135
         2000.world.hydro_hc.2000.FX             .1135
         2000.world.wind_ppl.1980.FX             .0159
         2000.world.wind_ppl.1990.FX             .0159
         2000.world.wind_ppl.2000.FX             .0159
         2000.world.solar_pv_ppl.1980.FX         .0038
         2000.world.solar_pv_ppl.1990.FX         .0038
         2000.world.solar_pv_ppl.2000.FX         .0038
         2000.world.ref_lol.1980.FX              .878
         2000.world.ref_lol.1990.FX              .878
         2000.world.ref_lol.2000.LO              .878
         2000.world.elec_t_d.1950.FX             .441
         2000.world.elec_t_d.1960.FX             .441
         2000.world.elec_t_d.1970.FX             .441
         2000.world.elec_t_d.1980.FX             .441
         2000.world.elec_t_d.1990.FX             .441
         2000.world.elec_t_d.2000.FX             .441
         2000.world.gas_t_d.1970.FX              1.083
         2000.world.gas_t_d.1980.FX              1.083
         2000.world.gas_t_d.1990.FX              1.083
         2000.world.gas_t_d.2000.FX              1.083
/ ;

PARAMETER r_bound_capacity_cumulated(period, model_region, technology, bound_type)
/
/ ;

PARAMETER r_bound_activity(period, model_region, technology, year, bound_type)
/
/ ;

PARAMETER r_bound_activity_cumulated(period, model_region, technology, bound_type)
/
* historic production in base year
         2000.world.coal_ppl.LO             .756
         2000.world.gas_cc.LO               .361
         2000.world.nuc_hc.LO               .292
         2000.world.bio_ppl.LO              .0276
         2000.world.hydro_hc.LO             .286
         2000.world.wind_ppl.LO             .0143
         2000.world.solar_pv_ppl.LO         .00285
         2000.world.ref_lol.LO              .878
* 0 limits in base year
         2000.world.h2_elec.UP              0
         2000.world.meth_coal.UP            0
         2000.world.meth_ng.UP              0
         2000.world.eth_bio.UP              0
* historic transition in end-use sectors
         2000.world.coal_solids.LO                       .869
         2010.world.coal_solids.LO                       .579
         2020.world.coal_solids.LO                       .290
         2000.world.biomass_solids.LO                    1.238
         2010.world.biomass_solids.LO                    .825
         2020.world.biomass_solids.LO                    .413
         2000.world.enduse_non_electric_gaseous.LO       1.732
         2010.world.enduse_non_electric_gaseous.LO       1.155
         2020.world.enduse_non_electric_gaseous.LO       .577
         2000.world.enduse_non_electric_liquids.LO       1.518
         2010.world.enduse_non_electric_liquids.LO       1.012
         2020.world.enduse_non_electric_liquids.LO       .506
*lower limits
         2010.world.hydro_hc.LO            .286
         2020.world.hydro_hc.LO            .286
         2030.world.hydro_hc.LO            .286
         2040.world.hydro_hc.LO            .286
         2050.world.hydro_hc.LO            .286
         2060.world.hydro_hc.LO            .286
         2070.world.hydro_hc.LO            .286
         2080.world.hydro_hc.LO            .286
         2090.world.hydro_hc.LO            .286
         2100.world.hydro_hc.LO            .286
* upper limits
         2000.world.bio_extr_1.UP          3.381
         2010.world.bio_extr_1.UP          3.381
         2020.world.bio_extr_1.UP          3.655
         2030.world.bio_extr_1.UP          3.862
         2040.world.bio_extr_1.UP          4.041
         2050.world.bio_extr_1.UP          4.195
         2060.world.bio_extr_1.UP          4.329
         2070.world.bio_extr_1.UP          4.446
         2080.world.bio_extr_1.UP          4.549
         2090.world.bio_extr_1.UP          4.640
         2100.world.bio_extr_1.UP          4.719
         2000.world.bio_extr_2.UP          .688
         2010.world.bio_extr_2.UP          .688
         2020.world.bio_extr_2.UP          1.007
         2030.world.bio_extr_2.UP          1.343
         2040.world.bio_extr_2.UP          1.668
         2050.world.bio_extr_2.UP          1.981
         2060.world.bio_extr_2.UP          2.280
         2070.world.bio_extr_2.UP          2.567
         2080.world.bio_extr_2.UP          2.842
         2090.world.bio_extr_2.UP          3.103
         2100.world.bio_extr_2.UP          3.350
         2010.world.hydro_hc.UP            .423
         2020.world.hydro_hc.UP            .559
         2030.world.hydro_hc.UP            .736
         2040.world.hydro_hc.UP            .920
         2050.world.hydro_hc.UP            1.098
         2060.world.hydro_hc.UP            1.253
         2070.world.hydro_hc.UP            1.377
         2080.world.hydro_hc.UP            1.470
         2090.world.hydro_hc.UP            1.535
         2100.world.hydro_hc.UP            1.580
* original wind potential set (linear increase until 2050, then constant)
         2010.world.wind_ppl.UP            .642
         2020.world.wind_ppl.UP            .910
         2030.world.wind_ppl.UP            1.177
         2040.world.wind_ppl.UP            1.445
         2050.world.wind_ppl.UP            1.712
         2060.world.wind_ppl.UP            1.712
         2070.world.wind_ppl.UP            1.712
         2080.world.wind_ppl.UP            1.712
         2090.world.wind_ppl.UP            1.712
         2100.world.wind_ppl.UP            1.712
         2010.world.wind_ppl2.UP           .728
         2020.world.wind_ppl2.UP           1.031
         2030.world.wind_ppl2.UP           1.334
         2040.world.wind_ppl2.UP           1.637
         2050.world.wind_ppl2.UP           1.941
         2060.world.wind_ppl2.UP           1.941
         2070.world.wind_ppl2.UP           1.941
         2080.world.wind_ppl2.UP           1.941
         2090.world.wind_ppl2.UP           1.941
         2100.world.wind_ppl2.UP           1.941
* solar PV MESSAGE B2 data
         2010.world.solar_pv_ppl.UP        .073
         2020.world.solar_pv_ppl.UP        .158
         2030.world.solar_pv_ppl.UP        .329
         2040.world.solar_pv_ppl.UP        .628
         2050.world.solar_pv_ppl.UP        1.041
         2060.world.solar_pv_ppl.UP        1.467
         2070.world.solar_pv_ppl.UP        1.809
         2080.world.solar_pv_ppl.UP        2.044
         2090.world.solar_pv_ppl.UP        2.198
         2100.world.solar_pv_ppl.UP        2.311
* share limits
         2000.world.enduse_non_electric_solids.UP        2.107
         2010.world.enduse_non_electric_solids.UP        1.982
         2020.world.enduse_non_electric_solids.UP        2.152
         2030.world.enduse_non_electric_solids.UP        1.672
         2040.world.enduse_non_electric_solids.UP        1.351
         2050.world.enduse_non_electric_solids.UP        1.052
         2060.world.enduse_non_electric_solids.UP        .992
         2070.world.enduse_non_electric_solids.UP        .995
         2080.world.enduse_non_electric_solids.UP        1.003
         2090.world.enduse_non_electric_solids.UP        .928
         2100.world.enduse_non_electric_solids.UP        .847
* end-use saving potentials
         2000.world.enduse_electric_save1.UP        0.000
         2010.world.enduse_electric_save1.UP        0.055
         2020.world.enduse_electric_save1.UP        0.110
         2030.world.enduse_electric_save1.UP        0.164
         2040.world.enduse_electric_save1.UP        0.219
         2050.world.enduse_electric_save1.UP        0.274
         2060.world.enduse_electric_save1.UP        0.329
         2070.world.enduse_electric_save1.UP        0.384
         2080.world.enduse_electric_save1.UP        0.439
         2090.world.enduse_electric_save1.UP        0.493
         2100.world.enduse_electric_save1.UP        0.548
         2000.world.enduse_electric_save2.UP        0.000
         2010.world.enduse_electric_save2.UP        0.018
         2020.world.enduse_electric_save2.UP        0.037
         2030.world.enduse_electric_save2.UP        0.055
         2040.world.enduse_electric_save2.UP        0.074
         2050.world.enduse_electric_save2.UP        0.092
         2060.world.enduse_electric_save2.UP        0.111
         2070.world.enduse_electric_save2.UP        0.129
         2080.world.enduse_electric_save2.UP        0.147
         2090.world.enduse_electric_save2.UP        0.166
         2100.world.enduse_electric_save2.UP        0.184
         2000.world.enduse_non_electric_save1.UP    0.000
         2010.world.enduse_non_electric_save1.UP    0.156
         2020.world.enduse_non_electric_save1.UP    0.312
         2030.world.enduse_non_electric_save1.UP    0.468
         2040.world.enduse_non_electric_save1.UP    0.624
         2050.world.enduse_non_electric_save1.UP    0.781
         2060.world.enduse_non_electric_save1.UP    0.937
         2070.world.enduse_non_electric_save1.UP    1.093
         2080.world.enduse_non_electric_save1.UP    1.249
         2090.world.enduse_non_electric_save1.UP    1.405
         2100.world.enduse_non_electric_save1.UP    1.561
         2000.world.enduse_non_electric_save2.UP    0.000
         2010.world.enduse_non_electric_save2.UP    0.208
         2020.world.enduse_non_electric_save2.UP    0.417
         2030.world.enduse_non_electric_save2.UP    0.625
         2040.world.enduse_non_electric_save2.UP    0.834
         2050.world.enduse_non_electric_save2.UP    1.042
         2060.world.enduse_non_electric_save2.UP    1.251
         2070.world.enduse_non_electric_save2.UP    1.459
         2080.world.enduse_non_electric_save2.UP    1.668
         2090.world.enduse_non_electric_save2.UP    1.876
         2100.world.enduse_non_electric_save2.UP    2.085
         2000.world.enduse_transport_save1.UP       0.000
         2010.world.enduse_transport_save1.UP       0.097
         2020.world.enduse_transport_save1.UP       0.194
         2030.world.enduse_transport_save1.UP       0.291
         2040.world.enduse_transport_save1.UP       0.388
         2050.world.enduse_transport_save1.UP       0.485
         2060.world.enduse_transport_save1.UP       0.582
         2070.world.enduse_transport_save1.UP       0.679
         2080.world.enduse_transport_save1.UP       0.775
         2090.world.enduse_transport_save1.UP       0.872
         2100.world.enduse_transport_save1.UP       0.969
         2000.world.enduse_transport_save2.UP       0.000
         2010.world.enduse_transport_save2.UP       0.126
         2020.world.enduse_transport_save2.UP       0.252
         2030.world.enduse_transport_save2.UP       0.378
         2040.world.enduse_transport_save2.UP       0.504
         2050.world.enduse_transport_save2.UP       0.630
         2060.world.enduse_transport_save2.UP       0.757
         2070.world.enduse_transport_save2.UP       0.883
         2080.world.enduse_transport_save2.UP       1.009
         2090.world.enduse_transport_save2.UP       1.135
         2100.world.enduse_transport_save2.UP       1.261
/ ;

PARAMETER bound_production_total(period, energycarrier, bound_type)
/
/ ;

PARAMETER bound_production_regional(period, model_region, energycarrier, bound_type)
/
/ ;

PARAMETER bound_production_sectoral(period, model_region, sector, energycarrier, bound_type)
/
/ ;

PARAMETER bound_consumption_total(period, energycarrier, bound_type)
/
/ ;

PARAMETER bound_consumption_regional(period, model_region, energycarrier, bound_type)
/
/ ;

PARAMETER bound_consumption_sectoral(period, model_region, sector, energycarrier, bound_type)
/
/ ;

PARAMETER bound_emission_total(period, emission, bound_type)
/
/ ;

PARAMETER bound_emission_regional(period, model_region, emission, bound_type)
/
/ ;

PARAMETER bound_emission_sectoral(period, model_region, sector, emission, bound_type)
/
/ ;

* historic data before base year of modeling set equal to base year 2000 data

LOOP(year $ (NOT period(year)),
         technical_lifetime(model_region, technology, year) = technical_lifetime(model_region, technology, '2000') ;
         economic_lifetime(model_region, technology, year) = economic_lifetime(model_region, technology, '2000') ;
         availability(model_region, technology, year) = availability(model_region, technology, '2000') ;
         inv_cost(model_region, technology, year) = inv_cost(model_region, technology, '2000') ;
         fix_cost(model_region, technology, year) = fix_cost(model_region, technology, '2000') ;
         var_cost(model_region, technology, year) = var_cost(model_region, technology, '2000') ;
         input(model_region, technology, energycarrier, level, year) = input(model_region, technology, energycarrier, level, '2000') ;
         output(model_region, technology, energycarrier, level, year) = output(model_region, technology, energycarrier, level, '2000') ;
         emission_output(model_region, technology, emission, year) = emission_output(model_region, technology, emission, '2000') ;
) ;
