SET year
/
        1950    '1950'
        1960    '1960'
        1970    '1970'
        1980    '1980'
        1990    '1990'
        2000    '2000'
        2010    '2010'
        2020    '2020'
        2030    '2030'
        2040    '2040'
        2050    '2050'
        2060    '2060'
        2070    '2070'
        2080    '2080'
        2090    '2090'
        2100    '2100'
/ ;

SET period(year)
/
        2000
        2010
        2020
        2030
        2040
        2050
        2060
        2070
        2080
        2090
        2100
/ ;

SET region
/
        world   'world'
/ ;

SET model_region(region)
/
        world
/ ;

SET trade_region(region)
/
/ ;

SET sector
/
        primary_energy  'primary energy sector'
        conversion      'conversion sector'
        end_use         'end-use sector'
/ ;

SET energycarrier
/
        oil_conventional         'conventional oil'
        oil_unconventional       'unconventional oil'
        oil                      'oil'
        gas_conventional         'conventional gas'
        gas_unconventional       'unconventional gas'
        gas                      'natural gas'
        coal                     'coal'
        biomass                  'biomass'
        hydro                    'hydro energy'
        wind                     'wind energy'
        solar                    'solar energy'
        nuclear                  'nuclear reactor fuel'
        electricity              'electricity'
        liquids                  'liquids'
        solids                   'solids'
        non_electric             'non-electric direct use'
        transport                'transportation fuels'
/ ;

SET level
/
        resource         'resource level'
        primary          'primary energy carrier level'
        secondary        'secondary energy carrier level'
        final            'final energy carrier level'
/ ;

SET energycarrier_level(energycarrier, level)
/
* resources
        oil_conventional.resource
        oil_unconventional.resource
        gas_conventional.resource
        gas_unconventional.resource
        coal.resource
* primary energy carriers
        oil.primary
        gas.primary
        coal.primary
        biomass.primary
        hydro.primary
        wind.primary
        solar.primary
        nuclear.primary
* secondary energy carriers
        electricity.secondary
        liquids.secondary
* final energy carriers (or groups)
        electricity.final
        liquids.final
        gas.final
        solids.final
        non_electric.final
        transport.final
/ ;

SET emission
/
        CO2     'carbon dioxide'
        CO2_CCS 'sequestered carbon dioxide'
/ ;

SET demand
/
         electric         'electric demand'
         non_electric     'non-electric demand for direct use'
         transport        'energy demand for transportation'
/ ;

SET technology
/
* resource extraction
         coal_extr
         oil_extr_1
         oil_extr_4
         gas_extr_1
         gas_extr_5
         bio_extr_1
         bio_extr_2
         nuc_imp
         hydro_pot
         wind_pot
         solar_pot
* power generation
         coal_ppl
         gas_cc
         nuc_hc
         bio_ppl
         hydro_hc
         wind_ppl
         wind_ppl2
         solar_pv_ppl
         backup_elc
* CCS
         g_ppl_co2scr
         c_ppl_co2scr
         bio_ppl_co2scr
* other conversion
         h2_elec
         meth_coal
         meth_ng
         eth_bio
         ref_lol
* transmission and distribution
         elec_t_d
         gas_t_d
         liquids_t_d
* end-use
         enduse_electric_std
         enduse_electric_save1
         enduse_electric_save2
         enduse_non_electric_std
         enduse_non_electric_save1
         enduse_non_electric_save2
         enduse_transport_std
         enduse_transport_save1
         enduse_transport_save2
* aggregation
         enduse_non_electric_liquids
         enduse_non_electric_solids
         enduse_non_electric_gaseous
         enduse_non_electric_electric
         enduse_transport_liquids
*         enduse_transport_electric
         coal_solids
         biomass_solids
/ ;

SET demand_technology(technology)
/
         enduse_electric_std
         enduse_electric_save1
         enduse_electric_save2
         enduse_non_electric_std
         enduse_non_electric_save1
         enduse_non_electric_save2
         enduse_transport_std
         enduse_transport_save1
         enduse_transport_save2
/ ;

SET upgrade(technology)
/
         g_ppl_co2scr
         c_ppl_co2scr
         bio_ppl_co2scr
/ ;

SET no_capacity(technology)
/
         nuc_imp
         hydro_pot
         wind_pot
         solar_pot
         liquids_t_d
         enduse_non_electric_liquids
         enduse_non_electric_solids
         enduse_non_electric_gaseous
         enduse_non_electric_electric
         enduse_transport_liquids
         coal_solids
         biomass_solids
/ ;

SET upgrade_correspondence(technology, technology)
/
         gas_cc.g_ppl_co2scr
         coal_ppl.c_ppl_co2scr
         bio_ppl.bio_ppl_co2scr
/ ;

SET demand_correspondence(region, technology, demand)
/
        world.enduse_electric_std.electric
        world.enduse_electric_save1.electric
        world.enduse_electric_save2.electric
        world.enduse_non_electric_std.non_electric
        world.enduse_non_electric_save1.non_electric
        world.enduse_non_electric_save2.non_electric
        world.enduse_transport_std.transport
        world.enduse_transport_save1.transport
        world.enduse_transport_save2.transport
/ ;

SET sectoral_technology(sector, technology)
/
        primary_energy.coal_extr
        primary_energy.oil_extr_1
        primary_energy.oil_extr_4
        primary_energy.gas_extr_1
        primary_energy.gas_extr_5
        primary_energy.bio_extr_1
        primary_energy.bio_extr_2
        primary_energy.nuc_imp
        primary_energy.hydro_pot
        primary_energy.wind_pot
        primary_energy.solar_pot
        conversion.coal_ppl
        conversion.gas_cc
        conversion.nuc_hc
        conversion.bio_ppl
        conversion.hydro_hc
        conversion.wind_ppl
        conversion.wind_ppl2
        conversion.solar_pv_ppl
        conversion.backup_elc
        conversion.g_ppl_co2scr
        conversion.c_ppl_co2scr
        conversion.bio_ppl_co2scr
        conversion.h2_elec
        conversion.meth_coal
        conversion.meth_ng
        conversion.eth_bio
        conversion.ref_lol
        conversion.elec_t_d
        conversion.gas_t_d
        conversion.liquids_t_d
        end_use.enduse_electric_std
        end_use.enduse_electric_save1
        end_use.enduse_electric_save2
        end_use.enduse_non_electric_std
        end_use.enduse_non_electric_save1
        end_use.enduse_non_electric_save2
        end_use.enduse_transport_std
        end_use.enduse_transport_save1
        end_use.enduse_transport_save2
        end_use.enduse_non_electric_liquids
        end_use.enduse_non_electric_solids
        end_use.enduse_non_electric_gaseous
        end_use.enduse_non_electric_electric
*        end_use.enduse_transport_electric
        end_use.enduse_transport_liquids
        end_use.coal_solids
        end_use.biomass_solids
/ ;

SET regional_sector(region, sector)
/
        world.primary_energy
        world.conversion
        world.end_use
/ ;

SET technology_regional_start(region, technology, year)
/
        world.coal_extr.2000
        world.oil_extr_1.2000
        world.oil_extr_4.2000
        world.gas_extr_1.2000
        world.gas_extr_5.2000
        world.bio_extr_1.2000
        world.bio_extr_2.2000
        world.nuc_imp.2000
        world.hydro_pot.2000
        world.wind_pot.2000
        world.solar_pot.2000
        world.coal_ppl.1980
        world.gas_cc.1980
        world.nuc_hc.1980
        world.bio_ppl.1980
        world.hydro_hc.1950
        world.wind_ppl.1980
        world.wind_ppl2.2000
        world.solar_pv_ppl.1980
        world.backup_elc.2000
        world.g_ppl_co2scr.2020
        world.c_ppl_co2scr.2020
        world.bio_ppl_co2scr.2020
        world.h2_elec.2000
        world.meth_coal.2000
        world.meth_ng.2000
        world.eth_bio.2000
        world.ref_lol.1980
        world.elec_t_d.1950
        world.gas_t_d.1970
        world.liquids_t_d.1970
        world.enduse_electric_std.2000
        world.enduse_electric_save1.2010
        world.enduse_electric_save2.2010
        world.enduse_non_electric_std.2000
        world.enduse_non_electric_save1.2010
        world.enduse_non_electric_save2.2010
        world.enduse_transport_std.2000
        world.enduse_transport_save1.2010
        world.enduse_transport_save2.2010
        world.enduse_non_electric_liquids.2000
        world.enduse_non_electric_solids.2000
        world.enduse_non_electric_gaseous.2000
        world.enduse_non_electric_electric.2000
*        world.enduse_transport_electric.2000
        world.enduse_transport_liquids.2000
        world.coal_solids.2000
        world.biomass_solids.2000
/ ;

*SET technology_interregional_start(region, region, technology, year)
*/
*/ ;

SET bound_type
/
        LO      'lower bound'
        UP      'upper bound'
        FX      'fixed bound'
/ ;

* stochastic scenarios

SET stochastic_scenario_all   'maximum number of stochastic scenarios'
    / stochastic1*stochastic50000 / ;
